@@ -1,11 +1,11 @@
 /* upslog.h - table of functions for handling various logging functions */
 
 /* function list */
-struct flist_t {
+typedef struct flist_s {
 	void	(*fptr)(const char *arg);
 	const	char	*arg;
-	struct	flist_t	*next;
-};
+	struct flist_s	*next;
+} flist_t;
 
 static void do_host(const char *arg);
 static void do_upshost(const char *arg);
