@@ -78,7 +78,7 @@ for each OID request we made), instead of sending many small packets
 /* Force numeric OIDs by disabling MIB loading */
 #define DISABLE_MIB_LOADING 1
 
-
+/* Parameters default values */
 #define DEFAULT_POLLFREQ	30		/* in seconds */
 
 /* use explicit booleans */
@@ -171,7 +171,6 @@ typedef struct {
 #define SU_VAR_VERSION		"snmp_version"
 #define SU_VAR_MIBS			"mibs"
 #define SU_VAR_POLLFREQ		"pollfreq"
-#define SU_VAR_SDTYPE		"sdtype"
 /* SNMP v3 related parameters */
 #define SU_VAR_SECLEVEL		"secLevel"
 #define SU_VAR_SECNAME		"secName"
@@ -234,7 +233,7 @@ bool_t su_ups_get(snmp_info_t *su_info_p);
 bool_t load_mib2nut(const char *mib);
 
 const char *su_find_infoval(info_lkp_t *oid2info, long value);
-long su_find_valinfo(info_lkp_t *oid2info, char* value);
+long su_find_valinfo(info_lkp_t *oid2info, const char* value);
 
 int su_setvar(const char *varname, const char *val);
 int su_instcmd(const char *cmdname, const char *extradata);
@@ -242,10 +241,10 @@ void su_shutdown_ups(void);
 
 void read_mibconf(char *mib);
 
-struct snmp_session g_snmp_sess, *g_snmp_sess_p;
-const char *OID_pwr_status;
-int g_pwr_battery;
-int pollfreq; /* polling frequency */
+extern struct snmp_session g_snmp_sess, *g_snmp_sess_p;
+extern const char *OID_pwr_status;
+extern int g_pwr_battery;
+extern int pollfreq; /* polling frequency */
 extern int input_phases, output_phases, bypass_phases;
 
 #endif /* SNMP_UPS_H */
