@@ -1,6 +1,8 @@
 /* state.h - Network UPS Tools common state management functions
 
-   Copyright (C) 2003  Russell Kroll <rkroll@exploits.org>
+   Copyright (C)
+	2003	Russell Kroll <rkroll@exploits.org>
+	2012	Arnaud Quette <arnaud.quette@free.fr>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -38,6 +40,7 @@ typedef struct st_tree_s {
 	int	aux;
 
 	struct enum_s		*enum_list;
+	struct range_s		*range_list;
 
 	struct st_tree_s	*left;
 	struct st_tree_s	*right;
@@ -45,11 +48,13 @@ typedef struct st_tree_s {
 
 int state_setinfo(st_tree_t **nptr, const char *var, const char *val);
 int state_addenum(st_tree_t *root, const char *var, const char *val);
+int state_addrange(st_tree_t *root, const char *var, const int min, const int max);
 int state_setaux(st_tree_t *root, const char *var, const char *auxs);
 const char *state_getinfo(st_tree_t *root, const char *var);
 int state_getflags(st_tree_t *root, const char *var);
 int state_getaux(st_tree_t *root, const char *var);
 const enum_t *state_getenumlist(st_tree_t *root, const char *var);
+const range_t *state_getrangelist(st_tree_t *root, const char *var);
 void state_setflags(st_tree_t *root, const char *var, int numflags, char **flags);
 int state_addcmd(cmdlist_t **list, const char *cmd);
 void state_infofree(st_tree_t *node);
@@ -57,6 +62,7 @@ void state_cmdfree(cmdlist_t *list);
 int state_delcmd(cmdlist_t **list, const char *cmd);
 int state_delinfo(st_tree_t **root, const char *var);
 int state_delenum(st_tree_t *root, const char *var, const char *val);
+int state_delrange(st_tree_t *root, const char *var, const int min, const int max);
 st_tree_t *state_tree_find(st_tree_t *node, const char *var);
 
 #endif /* STATE_H_SEEN */
