@@ -38,7 +38,7 @@ static snmp_device_id_t snmp_device_table[] = {
 	{ ".1.3.6.1.4.1.318.1.1.1.1.1.1.0" ,  "apcc", NULL},
 	{ ".1.3.6.1.4.1.4779.1.3.5.2.1.24.1" ,  "baytech", NULL},
 	{ ".1.3.6.1.4.1.3808.1.1.1.1.1.1.0" ,  "cyberpower", ".1.3.6.1.4.1.3808"},
-	{ "1.3.6.1.4.1.232.165.3.1.1.0" ,  "cpqpower", NULL},
+	{ ".1.3.6.1.4.1.232.165.3.1.1.0" ,  "cpqpower", ".1.3.6.1.4.1.232.165.3"},
 	{ ".1.3.6.1.4.1.4555.1.1.1.1.1.1.0" ,  "netvision", ".1.3.6.1.4.1.4555.1.1.1"},
         /* Terminating entry */
         { NULL, NULL, NULL}
