@@ -32,6 +32,7 @@ typedef struct {
 static usb_device_id_t usb_device_table[] = {
 
 	{ 0x0001, 0x0000, "blazer_usb" },
+	{ 0x03f0, 0x0001, "usbhid-ups" },
 	{ 0x03f0, 0x1f01, "bcmxcp_usb" },
 	{ 0x03f0, 0x1f02, "bcmxcp_usb" },
 	{ 0x03f0, 0x1f06, "usbhid-ups" },
@@ -40,6 +41,12 @@ static usb_device_id_t usb_device_table[] = {
 	{ 0x03f0, 0x1f0a, "usbhid-ups" },
 	{ 0x03f0, 0x1fe0, "usbhid-ups" },
 	{ 0x03f0, 0x1fe1, "usbhid-ups" },
+	{ 0x03f0, 0x1fe2, "usbhid-ups" },
+	{ 0x03f0, 0x1fe3, "usbhid-ups" },
+	{ 0x03f0, 0x1fe5, "usbhid-ups" },
+	{ 0x03f0, 0x1fe6, "usbhid-ups" },
+	{ 0x03f0, 0x1fe7, "usbhid-ups" },
+	{ 0x03f0, 0x1fe8, "usbhid-ups" },
 	{ 0x0463, 0x0001, "usbhid-ups" },
 	{ 0x0463, 0xffff, "usbhid-ups" },
 	{ 0x047c, 0xffff, "usbhid-ups" },
@@ -58,8 +65,11 @@ static usb_device_id_t usb_device_table[] = {
 	{ 0x0592, 0x0004, "usbhid-ups" },
 	{ 0x05b8, 0x0000, "blazer_usb" },
 	{ 0x0665, 0x5161, "blazer_usb" },
-	{ 0x06da, 0x0002, "bcmxcp_usb" },
+	{ 0x06da, 0x0002, "blazer_usb" },
 	{ 0x06da, 0x0003, "blazer_usb" },
+	{ 0x06da, 0x0004, "blazer_usb" },
+	{ 0x06da, 0x0005, "blazer_usb" },
+	{ 0x06da, 0x0201, "blazer_usb" },
 	{ 0x06da, 0xffff, "usbhid-ups" },
 	{ 0x075d, 0x0300, "usbhid-ups" },
 	{ 0x0764, 0x0005, "usbhid-ups" },
