@@ -29,6 +29,7 @@
 #define NUT_IPMI_DRV_NAME	"nut-ipmipsu"
 
 /* dynamic link library stuff */
+static char * libname = "libfreeipmi";
 static lt_dlhandle dl_handle = NULL;
 static const char *dl_error = NULL;
 
@@ -77,7 +78,7 @@ int nutscan_load_ipmi_library()
 		return 0;
 	}
 
-	dl_handle = lt_dlopenext("libfreeipmi");
+	dl_handle = lt_dlopenext(libname);
 	if (!dl_handle) {
 		dl_error = lt_dlerror();
 		goto err;
@@ -163,8 +164,9 @@ int nutscan_load_ipmi_library()
 
 	return 1;
 err:
-	fprintf(stderr, "%s\n", dl_error);
+        fprintf(stderr, "Cannot load IPMI library (%s) : %s. IPMI search disabled.\n", libname, dl_error);
 	dl_handle = (void *)1;
+	lt_dlexit();
 	return 0;
 }
 /* end of dynamic link library stuff */
